Pre-processing functions and saving intermediate data

add_predefined_vars(data, list_vars)

Arguments

data

a csv file contains abstract information. This could be the csv file downloaded from covidence

list_vars

a vector of data elements you want to extract. i.e. c("no_participants,"no_female","..")

Value

new dataset with additional empty columns

Examples

add_predefined_vars(abstracts,
                   c("no_participants", "no_aki", "age_mean", "age_sd"))
#> # A tibble: 50 × 16
#>    Title       Authors Abstract `Published Year` `Published Month` Journal DOI  
#>    <chr>       <chr>   <chr>               <dbl> <chr>             <chr>   <chr>
#>  1 "Developme… Palomb… Purpose…             2023 NA                BMC Ne… 10.1…
#>  2 "Risk fact… Contre… Backgro…             2023 NA                BMC Ne… 10.1…
#>  3 "Clinical … Bougue… Backgro…             2023 NA                Journa… 10.3…
#>  4 "Acute kid… Magalh… Introdu…             2023 NA                Intern… 10.1…
#>  5 "Sex diffe… Bugiar… Aims Pr…             2023 NA                Cardio… 10.1…
#>  6 "Mortality… Al Owe… COVID-1…             2023 NA                Journa… 10.3…
#>  7 "Frequency… Rashid… Backgro…             2023 NA                Shiraz… 10.5…
#>  8 "\"Acute k… De La … This st…             2023 NA                PLoS O… 10.1…
#>  9 "Outcomes … Al-Ome… Backgro…             2023 NA                Journa… 10.4…
#> 10 "Circulati… van Li… Introdu…             2023 NA                ERJ Op… 10.1…
#> # ℹ 40 more rows
#> # ℹ 9 more variables: `Covidence #` <chr>, no_participants_manual <lgl>,
#> #   no_aki_manual <lgl>, age_mean_manual <lgl>, age_sd_manual <lgl>,
#> #   no_participants_llm <lgl>, no_aki_llm <lgl>, age_mean_llm <lgl>,
#> #   age_sd_llm <lgl>