This function will save the training abstract data with empty columns to the processed data folder. This csv file will be used in the shinyapp 1 The data will be stored in metaextroctor_process_data

save_training_data(training_abs)

Arguments

training_abs

training abstracts including the variables you want to extract.

Value

a csv file saved in the metaextroctor_process_data file named training_stage_0_data.csv