R/glance_manual_app.R
glance_manual_app.RdThis function launches a Shiny app that displays each abstract alongside the data elements you want to extract. The app provides an interactive interface for manually entering this information, helping to fill out the _manual column generated by the `add_predefined_vars()` function in the training set.
glance_manual_app()Runs a shiny app.
if (interactive()) {
glance_manual_app()
}