This Shiny app allows you to manually review the results generated by the `process_with_ollama()` function. By uploading a testing dataset with LLM-extracted values, you can systematically check and validate each field filled out by the model.
manual_validation_app()Runs a shiny app.
if (interactive()) {
manual_validation_app()
}