This function will save the testing abstract data with empty columns to the processed data folder. This csv file will be used in the shinyapp 2 The data will be stored in metaextroctor_process_data
save_testing_data(testing_abs)a csv file saved in the metaextroctor_process_data file named training_stage_0_data.csv